@@ -7,6 +7,6 @@ from .series_extras import pack_data_for_series, get_series_padding, pack_input_
 from .rnn_extras import pack_input_data_for_rnn, pack_output_data_for_rnn
 from .scaler_extras import scale_input_data, scale_output_data, rescale_output_data
 from .input_extras import remove_not_used_inputs
-from .data_extras import prepare_input_data, prepare_output_data
+from .data_extras import prepare_input_data, prepare_output_data, pack_output_data_for_comparison_with_predictions
 from .encode_data_set import encode_inputs, encode_output_data, decode_output_data
 from .load_models import load_model
\ No newline at end of file
